# secret_checker
A Python module for checking if either of the secrets/environment variables include prod or dev or other env name.

# Installation
- Create a virtual environment
- Install the dependencies pip install -r requirements.txt

